Crate foxmark3

Crate foxmark3 

An interface to Proxmark3 devices which run the Iceman firmware.

Use of this library may be through commands executed by a Proxmark. This is the recommended way, when possible. In cases where there is no developed command API, raw request/response frames may be sent/received by a raw::Proxmark. It is possible to swap between these modes of use at runtime.

Feature Flags

  • serde: derives Serialize and Deserialize on card types
  • sqlx: implements Type, Encode, and Decode for card ID types

Re-exports

pub use crate::commands::Error;
pub use crate::commands::Proxmark;
pub use crate::commands::find;
pub use crate::commands::find_path;
pub use crate::commands::new;

Modules

commands
Device interface which allows execution of commands. This is an abstraction upon crate::raw.
raw
Device interface which allows the sending/receiving of requests/responses. For a more abstract interface, see crate::commands.